==> react-ui-library-2.4.0.tgz: package/src/stories/popover-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Button,
  Popover,
  Body1,
  theme
} from '../components'
const { majorScale } = theme

const PopoverContent = () =>
  <Pane width='240px' height='240px' display='flex' alignItems='center' justifyContent='center'>
    <Body1>Hello World</Body1>
  </Pane>

export default function popoverStory (module) {
  storiesOf('Popover', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Popover

Popovers display floating content in relation to a target.
Popovers appear either at the top or bottom of their target.
The preferred and default side is the bottom.
Popovers use smart positioning if there is not enough space on the bottom.

Popover contents are rendered in a newly created element appended to \`document.body\` using the \`Portal\` component.

Popovers wrap the single child target in a \`Box\` element.

When creating a popover, you must specify both:

* its content, by setting the \`content\` prop, and
* its target, as a single child element.

Popovers close on:

* outside click
* escape key
* window resize

\`\`\`
const PopoverContent = () =>
  <Pane width='240px' height='240px' display='flex' alignItems='center' justifyContent='center'>
    <Body1>Hello World</Body1>
  </Pane>

<Popover content={<PopoverContent />} display='inline-block' marginRight={majorScale(1)}>
  <Button primary>Hello world</Button>
</Popover>

<Popover side='top' content={<PopoverContent />} display='inline-block'>
  <Button primary>Hello world</Button>
</Popover>
\`\`\`

`}
          </Content>
          <Popover content={<PopoverContent />} display='inline-block' marginRight={majorScale(1)}>
            <Button primary>Trigger Bottom</Button>
          </Popover>
          <Popover side='top' content={<PopoverContent />} display='inline-block'>
            <Button primary>Trigger Top</Button>
          </Popover>
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`children\` | element.isRequired | \`undefined\` | the target
\`content\` | node.isRequired | \`undefined\` | content shown in the Popover
\`openClass\` | string | \`undefined\` | className added to the target
\`onOpen\` | func.isRequired | \`() => {}\` | on open callback
\`onClose\` | func.isRequired | \`() => {}\` | on close callback
\`side\` | oneOf(['bottom', 'top']) | \`bottom\` | preferred side to show Popover
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('smart positioning', () => (
      <App>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' primary>Top Left</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' top={0} right={0} primary>Top Right</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' top={0} right='50%' primary>Top</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' top='50%' right='50%' primary>Center</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} left={0} primary>Bottom Left</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} right='50%' primary>Bottom Center</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} right={0} primary>Bottom Right</Button>
        </Popover>
      </App>
    ))
}

==> react-ui-library-2.4.1.tgz: package/src/stories/popover-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  Button,
  Popover,
  Body1,
  theme
} from '../components'
const { majorScale } = theme

const PopoverContent = () =>
  <Pane width='240px' height='240px' display='flex' alignItems='center' justifyContent='center'>
    <Body1>Hello World</Body1>
  </Pane>

export default function popoverStory (module) {
  storiesOf('Popover', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Popover

Popovers display floating content in relation to a target.
Popovers appear either at the top or bottom of their target.
The preferred and default side is the bottom.
Popovers use smart positioning if there is not enough space on the bottom.

Popover contents are rendered in a newly created element appended to \`document.body\` using the \`Portal\` component.

Popovers wrap the single child target in a \`Box\` element.

When creating a popover, you must specify both:

* its content, by setting the \`content\` prop, and
* its target, as a single child element.

Popovers close on:

* outside click
* escape key
* window resize

\`\`\`
const PopoverContent = () =>
  <Pane width='240px' height='240px' display='flex' alignItems='center' justifyContent='center'>
    <Body1>Hello World</Body1>
  </Pane>

<Popover content={<PopoverContent />} display='inline-block' marginRight={majorScale(1)}>
  <Button primary>Hello world</Button>
</Popover>

<Popover side='top' content={<PopoverContent />} display='inline-block'>
  <Button primary>Hello world</Button>
</Popover>
\`\`\`

`}
          </Content>
          <Popover content={<PopoverContent />} display='inline-block' marginRight={majorScale(1)}>
            <Button primary>Trigger Bottom</Button>
          </Popover>
          <Popover side='top' content={<PopoverContent />} display='inline-block'>
            <Button primary>Trigger Top</Button>
          </Popover>
          <Content markdown>
            {`
prop | type | default | description
-----|------| --------|-------------
\`children\` | element.isRequired | \`undefined\` | the target
\`content\` | node.isRequired | \`undefined\` | content shown in the Popover
\`openClass\` | string | \`undefined\` | className added to the target
\`onOpen\` | func.isRequired | \`() => {}\` | on open callback
\`onClose\` | func.isRequired | \`() => {}\` | on close callback
\`side\` | \`bottom\`, \`top\` | \`bottom\` | preferred side to show Popover
\`useSmartPositioning\` | bool | \`true\` | toggle smart positioning
\`useArrow\` | bool | \`false\` | don't use the arrow in app
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('smart positioning', () => (
      <App>
        <Popover useSmartPositioning={false} content={<PopoverContent />}>
          <Button position='absolute' primary>Top Left</Button>
        </Popover>
        <Popover useSmartPositioning={false} content={<PopoverContent />}>
          <Button position='absolute' top={0} right={0} primary>Top Right</Button>
        </Popover>
        <Popover useSmartPositioning={false} content={<PopoverContent />}>
          <Button position='absolute' top={0} right='50%' primary>Top</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' top='50%' right='50%' primary>Center</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} left={0} primary>Bottom Left</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} right='50%' primary>Bottom Center</Button>
        </Popover>
        <Popover content={<PopoverContent />}>
          <Button position='absolute' bottom={0} right={0} primary>Bottom Right</Button>
        </Popover>
      </App>
    ))
}
